Learn R Programming

sBIC (version 0.2.0)

sBIC: Compute the sBIC.

Description

Computes the sBIC for a given collection of models.

Usage

sBIC(X, mod)

Arguments

X
the data for which the maximum likelihood estimates will be computed for the given collection of models. To see how this data should be formatted check the documentation for setData.YourModelName (e.g. setData.LCAs). If X is NULL then it is assumed that data for the model has already been set, this can be useful if you want to compute the sBIC with the same model and data several times (perhaps after changing some parameter of the model) without having to reset the data and thus recompute maximum log-likelihoods.
mod
an object representing a poset of models of the same type, e.g. a collection of binomial mixture models. The currently implemented models include:

Value

A named list containing the components
  • logLike - the computed MLE log-likelihoods for each model.
  • sBIC - the sBIC score for each model.
  • BIC - the usual BIC score for each model.
  • modelPoset - the input model poset mod.