X
the data for which the maximum likelihood estimates will be computed
for the given collection of models. To see how this data should be
formatted check the documentation for setData.YourModelName (e.g.
setData.LCAs). If X is NULL then it is assumed that data for the
model has already been set, this can be useful if you want to
compute the sBIC with the same model and data several times (perhaps
after changing some parameter of the model) without having to reset
the data and thus recompute maximum log-likelihoods.